@@ -8,14 +8,12 @@ from oms_cms.backend.pages.views import get_page
 class OmsPageFallbackMiddleware(MiddlewareMixin):
     def process_response(self, request, response):
         if response.status_code != 404:
-            return response  # No need to check for a flatpage for non-404 responses.
+            return response
         try:
             return get_page(request, request.path_info)
-        # Return the original response if any errors happened. Because this
-        # is a middleware, we can't assume the errors will be caught elsewhere.
         except Http404:
             return response
         except Exception:
             if settings.DEBUG:
                 raise
-            return response
\ No newline at end of file
+            return response
